==> haskell-aeson-qq-0.8.2-104-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-ETfRQ8sKrmDGE90KJEkP1H
key: aeson-qq-0.8.2-ETfRQ8sKrmDGE90KJEkP1H
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
author: Oscar Finnsson
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
abi: e2cd3e599d6de8ee908a800124c1402e
exposed: True
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
import-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-ETfRQ8sKrmDGE90KJEkP1H
depends:
    aeson-1.4.2.0-3Fy8y4TZyLW38WYgCKr7yc
    attoparsec-0.13.2.2-4iFLH0ONEYhG16eDwwtqQO base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    haskell-src-meta-0.8.2-8ADbVF5VqZcIuW9XL3cCSz parsec-3.1.13.0
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR template-haskell-2.14.0.0
    text-1.2.3.1 vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.2-116-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-LJMxdaRfr0KHG8YlxxVol3
key: aeson-qq-0.8.2-LJMxdaRfr0KHG8YlxxVol3
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
author: Oscar Finnsson
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
abi: 5848f737edfeea1f72d0ac0d49004e85
exposed: True
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-LJMxdaRfr0KHG8YlxxVol3
depends:
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L
    attoparsec-0.13.2.2-IaNz9bz10S32KGLwZomjal base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    haskell-src-meta-0.8.2-7lXwR5nNFOw3PIU2Y5V5RO parsec-3.1.13.0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b template-haskell-2.14.0.0
    text-1.2.3.1 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
